@@ -251,7 +251,11 @@ impl App {
             let render_new_devices = !selected_controller.new_devices.is_empty()
                 | selected_controller.is_scanning.load(Ordering::Relaxed);
 
-            let adapter_block_height = self.controllers.len() as u16 + 6;
+            if !render_new_devices && self.focused_block == FocusedBlock::NewDevices {
+                self.focused_block = FocusedBlock::PairedDevices;
+            }
+
+            let adapter_block_height = self.controllers.len() as u16 + 4;
 
             let paired_devices_block_height = selected_controller.paired_devices.len() as u16 + 4;
 
@@ -263,14 +267,14 @@ impl App {
                             Constraint::Length(paired_devices_block_height),
                             Constraint::Fill(1),
                             Constraint::Length(adapter_block_height),
-                            Constraint::Length(1),
+                            Constraint::Length(2),
                         ]
                     } else {
                         [
                             Constraint::Fill(1),
                             Constraint::Length(0),
                             Constraint::Length(adapter_block_height),
-                            Constraint::Length(1),
+                            Constraint::Length(2),
                         ]
                     })
                     .margin(1)
@@ -302,9 +306,9 @@ impl App {
             let widths = [
                 Constraint::Length(10),
                 Constraint::Length(10),
-                Constraint::Length(10),
-                Constraint::Length(10),
-                Constraint::Length(14),
+                Constraint::Length(5),
+                Constraint::Length(8),
+                Constraint::Length(12),
             ];
 
             let rows_len = rows.len();
@@ -323,28 +327,12 @@ impl App {
                         .bottom_margin(1)
                     } else {
                         Row::new(vec![
-                            Cell::from("Name").style(match self.color_mode {
-                                ColorMode::Dark => Style::default().fg(Color::White),
-                                ColorMode::Light => Style::default().fg(Color::Black),
-                            }),
-                            Cell::from("Alias").style(match self.color_mode {
-                                ColorMode::Dark => Style::default().fg(Color::White),
-                                ColorMode::Light => Style::default().fg(Color::Black),
-                            }),
-                            Cell::from("Power").style(match self.color_mode {
-                                ColorMode::Dark => Style::default().fg(Color::White),
-                                ColorMode::Light => Style::default().fg(Color::Black),
-                            }),
-                            Cell::from("Pairable").style(match self.color_mode {
-                                ColorMode::Dark => Style::default().fg(Color::White),
-                                ColorMode::Light => Style::default().fg(Color::Black),
-                            }),
-                            Cell::from("Discoverable").style(match self.color_mode {
-                                ColorMode::Dark => Style::default().fg(Color::White),
-                                ColorMode::Light => Style::default().fg(Color::Black),
-                            }),
+                            Cell::from("Name"),
+                            Cell::from("Alias"),
+                            Cell::from("Power"),
+                            Cell::from("Pairable"),
+                            Cell::from("Discoverable"),
                         ])
-                        .style(Style::new().bold())
                         .bottom_margin(1)
                     }
                 })
@@ -374,11 +362,7 @@ impl App {
                             }
                         }),
                 )
-                .style(match self.color_mode {
-                    ColorMode::Dark => Style::default().fg(Color::White),
-                    ColorMode::Light => Style::default().fg(Color::Black),
-                })
-                .highlight_symbol("  ")
+                .flex(ratatui::layout::Flex::SpaceAround)
                 .row_highlight_style(if self.focused_block == FocusedBlock::Adapter {
                     Style::default().bg(Color::DarkGray).fg(Color::White)
                 } else {
@@ -479,8 +463,8 @@ impl App {
 
             let mut widths = vec![
                 Constraint::Max(25),
-                Constraint::Length(10),
-                Constraint::Length(10),
+                Constraint::Length(7),
+                Constraint::Length(9),
             ];
 
             if show_battery_column {
@@ -501,24 +485,11 @@ impl App {
                             .bottom_margin(1)
                         } else {
                             Row::new(vec![
-                                Cell::from("Name").style(match self.color_mode {
-                                    ColorMode::Dark => Style::default().fg(Color::White),
-                                    ColorMode::Light => Style::default().fg(Color::Black),
-                                }),
-                                Cell::from("Trusted").style(match self.color_mode {
-                                    ColorMode::Dark => Style::default().fg(Color::White),
-                                    ColorMode::Light => Style::default().fg(Color::Black),
-                                }),
-                                Cell::from("Connected").style(match self.color_mode {
-                                    ColorMode::Dark => Style::default().fg(Color::White),
-                                    ColorMode::Light => Style::default().fg(Color::Black),
-                                }),
-                                Cell::from("Battery").style(match self.color_mode {
-                                    ColorMode::Dark => Style::default().fg(Color::White),
-                                    ColorMode::Light => Style::default().fg(Color::Black),
-                                }),
+                                Cell::from("Name"),
+                                Cell::from("Trusted"),
+                                Cell::from("Connected"),
+                                Cell::from("Battery"),
                             ])
-                            .style(Style::new().bold())
                             .bottom_margin(1)
                         }
                     } else if self.focused_block == FocusedBlock::PairedDevices {
@@ -574,11 +545,7 @@ impl App {
                             }
                         }),
                 )
-                .style(match self.color_mode {
-                    ColorMode::Dark => Style::default().fg(Color::White),
-                    ColorMode::Light => Style::default().fg(Color::Black),
-                })
-                .highlight_symbol("  ")
+                .flex(ratatui::layout::Flex::SpaceAround)
                 .row_highlight_style(if self.focused_block == FocusedBlock::PairedDevices {
                     Style::default().bg(Color::DarkGray).fg(Color::White)
                 } else {
@@ -609,6 +576,7 @@ impl App {
 
             //New devices
 
+            let mut max_name_width = 20;
             if render_new_devices {
                 let rows: Vec<Row> = selected_controller
                     .new_devices
@@ -618,6 +586,9 @@ impl App {
                             if let Some(icon) = &d.icon {
                                 format!("{} {}", icon, &d.alias)
                             } else {
+                                if d.alias.len() > max_name_width {
+                                    max_name_width = d.alias.len();
+                                }
                                 d.alias.to_owned()
                             }
                         }])
@@ -625,7 +596,10 @@ impl App {
                     .collect();
                 let rows_len = rows.len();
 
-                let widths = [Constraint::Length(25), Constraint::Length(20)];
+                let widths = [
+                    Constraint::Length(20),
+                    Constraint::Length(max_name_width.try_into().unwrap()),
+                ];
 
                 let new_devices_table = Table::new(rows, widths)
                     .header({
@@ -637,22 +611,13 @@ impl App {
                             .style(Style::new().bold())
                             .bottom_margin(1)
                         } else {
-                            Row::new(vec![
-                                Cell::from("Address").style(match self.color_mode {
-                                    ColorMode::Dark => Style::default().fg(Color::White),
-                                    ColorMode::Light => Style::default().fg(Color::Black),
-                                }),
-                                Cell::from("Name").style(match self.color_mode {
-                                    ColorMode::Dark => Style::default().fg(Color::White),
-                                    ColorMode::Light => Style::default().fg(Color::Black),
-                                }),
-                            ])
-                            .style(Style::new().bold())
-                            .bottom_margin(1)
+                            Row::new(vec![Cell::from("Address"), Cell::from("Name")])
+                                .bottom_margin(1)
                         }
                     })
                     .block(
                         Block::default()
+                            .padding(Padding::horizontal(1))
                             .title({
                                 if selected_controller.is_scanning.load(Ordering::Relaxed) {
                                     format!(" Scanning {} ", self.spinner.draw())
@@ -683,11 +648,7 @@ impl App {
                                 }
                             }),
                     )
-                    .style(match self.color_mode {
-                        ColorMode::Dark => Style::default().fg(Color::White),
-                        ColorMode::Light => Style::default().fg(Color::Black),
-                    })
-                    .highlight_symbol("  ")
+                    .flex(ratatui::layout::Flex::SpaceAround)
                     .row_highlight_style(if self.focused_block == FocusedBlock::NewDevices {
                         Style::default().bg(Color::DarkGray).fg(Color::White)
                     } else {
@@ -720,32 +681,66 @@ impl App {
 
             // Help
             let help = match self.focused_block {
-                FocusedBlock::PairedDevices => Line::from(vec![
-                    Span::from("k,").bold(),
-                    Span::from("  Up"),
-                    Span::from(" | "),
-                    Span::from("j,").bold(),
-                    Span::from("  Down"),
-                    Span::from(" | "),
-                    Span::from("s").bold(),
-                    Span::from("  Scan on/off"),
-                    Span::from(" | "),
-                    Span::from(self.config.paired_device.unpair.to_string()).bold(),
-                    Span::from("  Unpair"),
-                    Span::from(" | "),
-                    Span::from("󱁐  or ↵ ").bold(),
-                    Span::from(" Dis/Connect"),
-                    Span::from(" | "),
-                    Span::from(self.config.paired_device.toggle_trust.to_string()).bold(),
-                    Span::from(" Un/Trust"),
-                    Span::from(" | "),
-                    Span::from(self.config.paired_device.rename.to_string()).bold(),
-                    Span::from(" Rename"),
-                    Span::from(" | "),
-                    Span::from("⇄").bold(),
-                    Span::from(" Nav"),
-                ]),
-                FocusedBlock::NewDevices => Line::from(vec![
+                FocusedBlock::PairedDevices => {
+                    if frame.area().width > 103 {
+                        vec![Line::from(vec![
+                            Span::from("k,").bold(),
+                            Span::from("  Up"),
+                            Span::from(" | "),
+                            Span::from("j,").bold(),
+                            Span::from("  Down"),
+                            Span::from(" | "),
+                            Span::from("s").bold(),
+                            Span::from("  Scan on/off"),
+                            Span::from(" | "),
+                            Span::from(self.config.paired_device.unpair.to_string()).bold(),
+                            Span::from("  Unpair"),
+                            Span::from(" | "),
+                            Span::from("󱁐  or ↵ ").bold(),
+                            Span::from(" Dis/Connect"),
+                            Span::from(" | "),
+                            Span::from(self.config.paired_device.toggle_trust.to_string()).bold(),
+                            Span::from(" Un/Trust"),
+                            Span::from(" | "),
+                            Span::from(self.config.paired_device.rename.to_string()).bold(),
+                            Span::from(" Rename"),
+                            Span::from(" | "),
+                            Span::from("⇄").bold(),
+                            Span::from(" Nav"),
+                        ])]
+                    } else {
+                        vec![
+                            Line::from(vec![
+                                Span::from("󱁐  or ↵ ").bold(),
+                                Span::from(" Dis/Connect"),
+                                Span::from(" | "),
+                                Span::from("s").bold(),
+                                Span::from("  Scan on/off"),
+                                Span::from(" | "),
+                                Span::from(self.config.paired_device.unpair.to_string()).bold(),
+                                Span::from("  Unpair"),
+                            ]),
+                            Line::from(vec![
+                                Span::from(self.config.paired_device.toggle_trust.to_string())
+                                    .bold(),
+                                Span::from(" Un/Trust"),
+                                Span::from(" | "),
+                                Span::from(self.config.paired_device.rename.to_string()).bold(),
+                                Span::from(" Rename"),
+                                Span::from(" | "),
+                                Span::from("k,").bold(),
+                                Span::from("  Up"),
+                                Span::from(" | "),
+                                Span::from("j,").bold(),
+                                Span::from("  Down"),
+                                Span::from(" | "),
+                                Span::from("⇄").bold(),
+                                Span::from(" Nav"),
+                            ]),
+                        ]
+                    }
+                }
+                FocusedBlock::NewDevices => vec![Line::from(vec![
                     Span::from("k,").bold(),
                     Span::from("  Up"),
                     Span::from(" | "),
@@ -760,8 +755,8 @@ impl App {
                     Span::from(" | "),
                     Span::from("⇄").bold(),
                     Span::from(" Nav"),
-                ]),
-                FocusedBlock::Adapter => Line::from(vec![
+                ])],
+                FocusedBlock::Adapter => vec![Line::from(vec![
                     Span::from("s").bold(),
                     Span::from("  Scan on/off"),
                     Span::from(" | "),
@@ -776,15 +771,23 @@ impl App {
                     Span::from(" | "),
                     Span::from("⇄").bold(),
                     Span::from(" Nav"),
-                ]),
+                ])],
                 FocusedBlock::SetDeviceAliasBox => {
-                    Line::from(vec![Span::from("󱊷 ").bold(), Span::from(" Discard")])
+                    vec![Line::from(vec![
+                        Span::from("󱊷 ").bold(),
+                        Span::from(" Discard"),
+                    ])]
                 }
                 FocusedBlock::PassKeyConfirmation => {
-                    Line::from(vec![Span::from("󱊷 ").bold(), Span::from(" Discard")])
+                    vec![Line::from(vec![
+                        Span::from("󱊷 ").bold(),
+                        Span::from(" Discard"),
+                    ])]
                 }
             };
-            frame.render_widget(help.centered().blue(), help_block);
+
+            let help = Paragraph::new(help).centered().blue();
+            frame.render_widget(help, help_block);
 
             // Pairing confirmation
 
